@@ -33,6 +33,8 @@ from tvb.datatypes.tracts import Tracts
 
 
 class TractsH5(H5File):
+    MAX_N_VERTICES = 2 ** 16
+
     def __init__(self, path):
         super(TractsH5, self).__init__(path)
         self.vertices = DataSet(Tracts.vertices, self, expand_dimension=0)
@@ -47,9 +49,8 @@ class TractsH5(H5File):
         start, end = self.tract_start_idx[i:i + 2]
         return self.vertices[start:end]
 
-    # fixme: these are broken, they have to live at a higher level
     def _get_tract_ids(self, region_id):
-        tract_ids = numpy.where(self.tract_region == region_id)[0]
+        tract_ids = numpy.where(self.tract_region.load() == region_id)[0]
         return tract_ids
 
     def _get_track_ids_webgl_chunks(self, region_id):
@@ -67,15 +68,14 @@ class TractsH5(H5File):
 
         count = 0
         tidx = 0
-        tract_start_idx = self.tract_start_idx  # traits make . expensive
 
         while tidx < len(tract_ids):  # tidx always grows
             tid = tract_ids[tidx]
-            start, end = tract_start_idx[tid:tid + 2]
+            start, end = self.tract_start_idx[tid:tid + 2]
             track_len = end - start
 
             if track_len >= self.MAX_N_VERTICES:
-                raise ValueError('cannot yet handle very long tracts')
+                raise ValueError('Currently tracts are too long to be handled!')
 
             count += track_len
 
@@ -92,11 +92,6 @@ class TractsH5(H5File):
         if chunk:
             tract_id_chunks.append(chunk)
 
-        # q = []
-        # for a in tract_id_chunks:
-        #     q.extend(a)
-        # assert (numpy.array(q) == tract_ids).all()
-
         return tract_id_chunks
 
     def get_vertices(self, region_id, slice_number=0):
@@ -114,7 +109,7 @@ class TractsH5(H5File):
         for tid in tract_ids:
             tracts_vertices.append(self.get_tract(tid))
 
-        self.close_file()
+        self.close()
 
         if tracts_vertices:
             tracts_vertices = numpy.concatenate(tracts_vertices)
@@ -147,10 +142,6 @@ class TractsH5(H5File):
 
         return chunk_line_starts
 
-    def get_urls_for_rendering(self):
-        return ('/flow/read_datatype_attribute/' + self.gid + '/get_line_starts/False',
-                '/flow/read_binary_datatype_attribute/' + self.gid + '/get_vertices')
-
     def write_vertices_slice(self, partial_result):
         """
         Append a new value to the ``vertices`` attribute.
