@@ -36,16 +36,19 @@ Class responsible for all TVB exports (datatype or project).
 
 import os
 from datetime import datetime
-from tvb.adapters.exporters.TVBLinkedExporter import TVBLinkedExporter
-from tvb.adapters.exporters.tvb_export import TVBExporter
+
 from tvb.adapters.exporters.exceptions import ExportException, InvalidExportDataException
-from tvb.basic.profile import TvbProfile
+from tvb.adapters.exporters.tvb_export import TVBExporter
+from tvb.adapters.exporters.tvb_linked_export import TVBLinkedExporter
 from tvb.basic.logger.builder import get_logger
+from tvb.basic.profile import TvbProfile
 from tvb.config import TVB_IMPORTER_MODULE, TVB_IMPORTER_CLASS
-from tvb.core.entities.model import model_operation
 from tvb.core.entities.file.files_helper import FilesHelper, TvbZip
+from tvb.core.entities.model import model_operation
 from tvb.core.entities.storage import dao
 from tvb.core.neocom import h5
+from tvb.core.neotraits.h5 import H5File
+from tvb.core.services.project_service import ProjectService
 
 
 class ExportManager(object):
@@ -55,6 +58,8 @@ class ExportManager(object):
     all_exporters = {}  # Dictionary containing all available exporters
     export_folder = None
     EXPORT_FOLDER_NAME = "EXPORT_TMP"
+    EXPORTED_SIMULATION_NAME = "exported_simulation"
+    EXPORTED_SIMULATION_DTS_DIR = "datatypes"
     ZIP_FILE_EXTENSION = "zip"
     logger = get_logger(__name__)
 
@@ -64,6 +69,7 @@ class ExportManager(object):
         self._register_exporter(TVBExporter())
         self._register_exporter(TVBLinkedExporter())
         self.export_folder = os.path.join(TvbProfile.current.TVB_STORAGE, self.EXPORT_FOLDER_NAME)
+        self.files_helper = FilesHelper()
 
     def _register_exporter(self, exporter):
         """
@@ -101,7 +107,7 @@ class ExportManager(object):
         :param data: data type to be exported
         :param exporter_id: identifier of the exporter to be used
         :param project: project that contains data to be exported
-            
+
         :returns: a tuple with the following elements
             1. name of the file to be shown to user
             2. full path of the export file (available for download)
@@ -121,7 +127,7 @@ class ExportManager(object):
         if project is None:
             raise ExportException("Please provide the project where data files are stored")
 
-        # Now we start the real export        
+        # Now we start the real export
         if not exporter.accepts(data):
             raise InvalidExportDataException("Current data can not be exported by specified exporter")
 
@@ -139,25 +145,8 @@ class ExportManager(object):
 
         return export_data
 
-    def _get_linked_datatypes_storage_path(self, project):
-        """
-        :return: the file paths to the datatypes that are linked in `project`
-        """
-        paths = []
-        for lnk_dt in dao.get_linked_datatypes_in_project(project.id):
-            # get datatype as a mapped type
-            lnk_dt = dao.get_datatype_by_gid(lnk_dt.gid)
-            path = h5.path_for_stored_index(lnk_dt)
-            if path is not None:
-                paths.append(path)
-            else:
-                self.logger.warning("Problem when trying to retrieve path on %s:%s for "
-                                    "export!" % (lnk_dt.type, lnk_dt.gid))
-        return paths
-
     def _export_linked_datatypes(self, project, zip_file):
-        files_helper = FilesHelper()
-        linked_paths = self._get_linked_datatypes_storage_path(project)
+        linked_paths = ProjectService().get_linked_datatypes_storage_path(project)
 
         if not linked_paths:
             # do not export an empty operation
@@ -172,7 +161,7 @@ class ExportManager(object):
         op.start_now()
         op.mark_complete(model_operation.STATUS_FINISHED)
 
-        op_folder = files_helper.get_operation_folder(op.project.name, op.id)
+        op_folder = self.files_helper.get_operation_folder(op.project.name, op.id)
         op_folder_name = os.path.basename(op_folder)
 
         # add linked datatypes to archive in the import operation
@@ -181,7 +170,7 @@ class ExportManager(object):
             zip_file.write(pth, zip_pth)
 
         # remove these files, since we only want them in export archive
-        files_helper.remove_folder(op_folder)
+        self.files_helper.remove_folder(op_folder)
 
     def export_project(self, project, optimize_size=False):
         """
@@ -192,8 +181,7 @@ class ExportManager(object):
         if project is None:
             raise ExportException("Please provide project to be exported")
 
-        files_helper = FilesHelper()
-        project_folder = files_helper.get_project_folder(project)
+        project_folder = self.files_helper.get_project_folder(project)
         project_datatypes = dao.get_datatypes_in_project(project.id, only_visible=optimize_size)
         to_be_exported_folders = []
         considered_op_ids = []
@@ -204,7 +192,7 @@ class ExportManager(object):
             for dt in project_datatypes:
                 op_id = dt.fk_from_operation
                 if op_id not in considered_op_ids:
-                    to_be_exported_folders.append({'folder': files_helper.get_project_folder(project, str(op_id)),
+                    to_be_exported_folders.append({'folder': self.files_helper.get_project_folder(project, str(op_id)),
                                                    'archive_path_prefix': str(op_id) + os.sep,
                                                    'exclude': folders_to_exclude})
                     considered_op_ids.append(op_id)
@@ -233,7 +221,8 @@ class ExportManager(object):
             # Make sure the Project.xml file gets copied:
             if optimize_size:
                 self.logger.debug("Done linked, now we write the project xml")
-                zip_file.write(files_helper.get_project_meta_file_path(project.name), files_helper.TVB_PROJECT_FILE)
+                zip_file.write(self.files_helper.get_project_meta_file_path(project.name),
+                               self.files_helper.TVB_PROJECT_FILE)
             self.logger.debug("Done, closing")
 
         return result_path
@@ -251,7 +240,7 @@ class ExportManager(object):
 
     def _build_data_export_folder(self, data):
         """
-        This method computes the folder where results of an export operation will be 
+        This method computes the folder where results of an export operation will be
         stored for a while (e.g until download is done; or for 1 day)
         """
         now = datetime.now()
@@ -259,8 +248,7 @@ class ExportManager(object):
                                              now.minute, now.second, now.microsecond)
         tmp_str = date_str + "@" + data.gid
         data_export_folder = os.path.join(self.export_folder, tmp_str)
-        files_helper = FilesHelper()
-        files_helper.check_created(data_export_folder)
+        self.files_helper.check_created(data_export_folder)
 
         return data_export_folder
 
@@ -269,16 +257,36 @@ class ExportManager(object):
         if burst is None:
             raise InvalidExportDataException("Could not find burst with ID " + str(burst_id))
 
-        op_folder = FilesHelper().get_project_folder(burst.project, str(burst.fk_simulation))
+        op_folder = self.files_helper.get_project_folder(burst.project, str(burst.fk_simulation))
+        tmp_export_folder = self._build_data_export_folder(burst)
+        tmp_sim_folder = os.path.join(tmp_export_folder, self.EXPORTED_SIMULATION_NAME)
+
+        if not os.path.exists(tmp_sim_folder):
+            os.makedirs(tmp_sim_folder)
+
+        all_view_model_paths, all_datatype_paths = h5.gather_references_of_view_model(burst.simulator_gid, op_folder)
+
+        burst_path = h5.determine_filepath(burst.gid, op_folder)
+        all_view_model_paths.append(burst_path)
+
+        for vm_path in all_view_model_paths:
+            dest = os.path.join(tmp_sim_folder, os.path.basename(vm_path))
+            self.files_helper.copy_file(vm_path, dest)
+
+        for dt_path in all_datatype_paths:
+            dest = os.path.join(tmp_sim_folder, self.EXPORTED_SIMULATION_DTS_DIR, os.path.basename(dt_path))
+            self.files_helper.copy_file(dt_path, dest)
+
+        main_vm_path = h5.determine_filepath(burst.simulator_gid, tmp_sim_folder)
+        H5File.remove_metadata_param(main_vm_path, 'history_gid')
 
         now = datetime.now()
         date_str = now.strftime("%Y-%m-%d_%H-%M")
         zip_file_name = "%s_%s.%s" % (date_str, str(burst_id), self.ZIP_FILE_EXTENSION)
-        tmp_export_folder = self._build_data_export_folder(burst)
+
         result_path = os.path.join(tmp_export_folder, zip_file_name)
-
         with TvbZip(result_path, "w") as zip_file:
-            for filename in os.listdir(op_folder):
-                zip_file.write(os.path.join(op_folder, filename), filename)
+            zip_file.write_folder(tmp_sim_folder)
 
+        self.files_helper.remove_folder(tmp_sim_folder)
         return result_path
