@@ -78,16 +78,10 @@ KEY_IS_RESTART = "tvbRestarted"
 KEY_INCLUDE_TOOLTIP = "includeTooltip"
 KEY_WRAP_CONTENT_IN_MAIN_DIV = "wrapContentInMainDiv"
 KEY_CURRENT_TAB = "currentTab"
-# TODO TVB-2670 See SelectedAdapterContext and other *Context classes, and try to put all Simulator related together
-KEY_BURST_CONFIG = 'burst_configuration'
-KEY_SIMULATOR_CONFIG = 'simulator_configuration'
-KEY_IS_SIMULATOR_COPY = 'is_simulator_copy'
-KEY_IS_SIMULATOR_LOAD = 'is_simulator_load'
-KEY_LAST_LOADED_FORM_URL = 'last_loaded_form_url'
+
 KEY_BACK_PAGE = "back_page_link"
 KEY_SECTION_TITLES = "section_titles"
 KEY_SUBSECTION_TITLES = "sub_section_titles"
-KEY_IS_SIMULATOR_BRANCH = "is_branch"
 
 # Overlay specific keys
 KEY_OVERLAY_TITLE = "overlay_title"
@@ -208,13 +202,8 @@ def get_current_project():
     return get_from_session(KEY_PROJECT)
 
 
-def clean_project_data_from_session():
+def remove_project_from_session():
     remove_from_session(KEY_PROJECT)
-    remove_from_session(KEY_SIMULATOR_CONFIG)
-    remove_from_session(KEY_LAST_LOADED_FORM_URL)
-    remove_from_session(KEY_BURST_CONFIG)
-    remove_from_session(KEY_IS_SIMULATOR_BRANCH)
-    add2session(KEY_IS_SIMULATOR_LOAD, False)
 
 
 class NotAllowed(TVBException):
