@@ -31,17 +31,20 @@
 """
 .. moduleauthor:: calin.pavel <calin.pavel@codemart.ro>
 """
-import pytest
 import os.path
 import shutil
 import zipfile
+import uuid
 from contextlib import closing
-from tvb.adapters.exporters.export_manager import ExportManager
+
+import pytest
 from tvb.adapters.exporters.exceptions import ExportException, InvalidExportDataException
+from tvb.adapters.exporters.export_manager import ExportManager
 from tvb.basic.profile import TvbProfile
+from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.entities.model.model_burst import BurstConfiguration
 from tvb.core.entities.storage import dao
-from tvb.core.entities.file.files_helper import FilesHelper
+from tvb.core.services.burst_service import BurstService
 from tvb.tests.framework.core.base_testcase import TransactionalTestCase
 from tvb.tests.framework.core.factory import TestFactory
 
@@ -93,9 +96,8 @@ class TestExporters(TransactionalTestCase):
         Test export of a data type which has no data stored on file system
         """
         datatype = dummy_datatype_index_factory()
-        file_name, file_path, _ = self.export_manager.export_data(datatype, self.TVB_EXPORTER, self.test_project)
+        _, file_path, _ = self.export_manager.export_data(datatype, self.TVB_EXPORTER, self.test_project)
 
-        assert file_name is not None, "Export process should return a file name"
         assert file_path is not None, "Export process should return path to export file"
         assert os.path.exists(file_path), "Could not find export file: %s on disk." % file_path
 
@@ -104,9 +106,8 @@ class TestExporters(TransactionalTestCase):
         Test export of a data type which has no data stored on file system
         """
         datatype = dummy_datatype_index_factory()
-        file_name, file_path, _ = self.export_manager.export_data(datatype, self.TVB_EXPORTER, self.test_project)
+        _, file_path, _ = self.export_manager.export_data(datatype, self.TVB_EXPORTER, self.test_project)
 
-        assert file_name is not None, "Export process should return a file name"
         assert file_path is not None, "Export process should return path to export file"
         assert os.path.exists(file_path), "Could not find export file: %s on disk." % file_path
 
@@ -179,17 +180,23 @@ class TestExporters(TransactionalTestCase):
         # Now check if the generated file is a correct ZIP file
         assert zipfile.is_zipfile(export_file), "Generated file is not a valid ZIP file"
 
-    def test_export_simulator_configuration(self, operation_factory):
+    def test_export_simulator_configuration(self, operation_factory, connectivity_index_factory):
         """
         Test export of a simulator configuration
         """
-        operation = operation_factory(is_simulation=True, store_vm=True)
+        conn_gid = uuid.UUID(connectivity_index_factory().gid)
+        operation = operation_factory(is_simulation=True, store_vm=True, test_project=self.test_project,
+                                      conn_gid=conn_gid)
 
         burst_configuration = BurstConfiguration(self.test_project.id)
         burst_configuration.fk_simulation = operation.id
         burst_configuration.simulator_gid = operation.view_model_gid
+        burst_configuration.name = "Test_burst"
         burst_configuration = dao.store_entity(burst_configuration)
 
+        op_folder = FilesHelper().get_project_folder(self.test_project, str(operation.id))
+        BurstService().store_burst_configuration(burst_configuration, op_folder)
+
         export_file = self.export_manager.export_simulator_configuration(burst_configuration.id)
 
         assert export_file is not None, "Export process should return path to export file"
